__title__ = 'customized_KoNLPy'
__version__ = '0.0.1'
__author__ = 'Lovit'
__license__ = 'GPL v3'
__copyright__ = 'Copyright 2017 Lovit'

from . import tag
from . import custom_tag
from .dictionary import CustomizedDictionary
from .utils import installpath
from .utils import loadtxt